Module block

Module block 

Bitcoin Block

A block is a bundle of transactions with a proof-of-work attached, which commits to an earlier block to form the blockchain. This module describes structures and functions needed to describe these blocks and the blockchain.

Structs

Block
A Bitcoin block, which is a collection of transactions with an attached proof of work.
BlockHeader
A block header, which contains all the block’s information except the actual transactions

Enums

Bip34Error
An error when looking up a BIP34 block height.